##  Step 3: Connect SAP LeanIX to Google Agent Engine
  1. In the administration area of SAP LeanIX, navigate to Integrations.
  2. Choose Add Integrations.
  3. Find Google Agent Engine and choose Configure.
  4. Enter a name for the integration.
  5. Copy the contents of the downloaded service key file from step 2 and paste it into the Enter Credentials field in SAP LeanIX.
![Configure Google Agent Engine dialog with a JSON credentials input field.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod4a0ebba40ca4b59807c12bcc484788c_LowRes.png)
Entering Credentials in SAP LeanIX Configuration
  6. Choose Finish.
